translate.storage.utx.UtxFile

Package translate :: Package storage :: Module utx :: Class UtxFile |
[hide private]
[frames] | no frames]

# Class UtxFile

source code

A UTX dictionary file

Nested Classes | [hide private]
Inherited from `base.TranslationStore`: `UnitClass`

Instance Methods | [hide private]
__init__(self, inputfile=None, unitclass=UtxUnit) Construct an UTX dictionary, optionally reading in from inputfile. | source code
_read_header(self, header=None) Read a UTX header | source code
_write_header(self) Create a UTX header | source code
getsourcelanguage(self) Gets the source language for this store | source code
setsourcelanguage(self, sourcelanguage) Sets the source language for this store | source code
gettargetlanguage(self) Gets the target language for this store | source code
settargetlanguage(self, targetlanguage) Sets the target language for this store | source code
parse(self, input) parsese the given file or file source string | source code
__str__(self) Converts to a string representation that can be parsed back using parsestring(). | source code
Inherited from `base.TranslationStore`: `__getstate__`, `__setstate__`, `add_unit_to_index`, `addsourceunit`, `addunit`, `detect_encoding`, `findid`, `findunit`, `findunits`, `getids`, `getprojectstyle`, `getunits`, `isempty`, `makeindex`, `remove_unit_from_index`, `require_index`, `save`, `savefile`, `setprojectstyle`, `translate`, `unit_iter` Inherited from `base.TranslationStore` (private): `_assignname` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Methods | [hide private]
Inherited from `base.TranslationStore`: `parsefile`, `parsestring`

Class Variables | [hide private]
| Name = `_("UTX Simple Dictionary")` The human usable name of this store type
| Mimetypes = `["text/x-utx"]` A list of MIME types associated with this store type
| Extensions = `["utx"]` A list of file extentions associated with this store type
Inherited from `base.TranslationStore`: `sourcelanguage`, `suggestions_in_format`, `targetlanguage` Inherited from `base.TranslationStore` (private): `_binary`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, inputfile=None, unitclass=UtxUnit) (Constructor) | source code
Construct an UTX dictionary, optionally reading in from inputfile. Overrides: object.__init__

### getsourcelanguage(self) | source code
Gets the source language for this store Overrides: base.TranslationStore.getsourcelanguage (inherited documentation)

### setsourcelanguage(self, sourcelanguage) | source code
Sets the source language for this store Overrides: base.TranslationStore.setsourcelanguage (inherited documentation)

### gettargetlanguage(self) | source code
Gets the target language for this store Overrides: base.TranslationStore.gettargetlanguage (inherited documentation)

### settargetlanguage(self, targetlanguage) | source code
Sets the target language for this store Overrides: base.TranslationStore.settargetlanguage (inherited documentation)

### parse(self, input) | source code
parsese the given file or file source string Overrides: base.TranslationStore.parse

### __str__(self) (Informal representation operator) | source code
Converts to a string representation that can be parsed back using parsestring(). Overrides: object.__str__ (inherited documentation)